==> moodle-1.4.5.tgz: moodle/lang/ms/forum.php <==
<?PHP // $Id: forum.php,v 1.1.6.1 2004/12/17 16:14:08 moodler Exp $ 
      // forum.php - created with Moodle 1.3.1 (2004052501)


$string['addanewdiscussion'] = 'Tambah topik perbincangan baru';
$string['addanewtopic'] = 'Tambah topik';
$string['allowchoice'] = 'Benarkan semua orang memilih';
$string['allowdiscussions'] = 'Bolehkah $a mengepos pada forum ini?';
$string['allowratings'] = 'Benarkan penghantaran dinilai?';
$string['allowsdiscussions'] = 'Forum ini membenarkan setiap orang untuk memulai sebuah topik perbincangan.';
$string['anyfile'] = 'Sebarang fail';
$string['attachment'] = 'Kepilan';
$string['bynameondate'] = 'dari $a->name - $a->date';
$string['configdisplaymode'] = 'Mod paparan asal untuk perbincangan jika belum ditetapkan.';
$string['configenablerssfeeds'] = 'Ini akan membenarkan RSS bagi semua forum. Anda masih perlu menukar setting RSS bagi setiap forum.';
$string['configlongpost'] = 'Sebarang pos melebihi had ini (tidak termasuk HTML) dianggap panjang.';
$string['configmanydiscussions'] = 'Bilangan perbincangan maksimum yang dipaparkan di dalam forum untuk setiap mukasurat';
$string['configmaxbytes'] = 'Sazi maximum bagi semua kepilan pada forum laman ini (bergantung kepada had kursus dll)';
$string['configreplytouser'] = 'Apabila pos forum dihantar, perlukah email pengguna disertakan sekali supaya penerima dapat menjawab terus kepadanya tanpa melalui forum? Walaupun disetkan kepada \'Ya\' pengguna boleh memilih untuk merahsiakan alamat email mereka.';
$string['configshortpost'] = 'Sebarang pos tidak melebihi had ini (tidak termasuk HTML) dianggap pendek.';
$string['couldnotadd'] = 'Tidak dapat menambahkan pos anda kerana kesalahan yang tidak diketahui';
$string['couldnotdeleteratings'] = 'Maaf, tidak dapat dipadamkan kerana ianya telah dinilai.';
$string['couldnotdeletereplies'] = 'Maaf, tidak dapat dipadamkan kerana ianya telah dibalas.';
$string['couldnotupdate'] = 'Tidak dapat mengemaskini pos anda kerana kesalahan yang tidak diketahui';
$string['delete'] = 'Hapus';
$string['deleteddiscussion'] = 'Topik perbincangan telah dihapuskan';
$string['deletedpost'] = 'Pos telah dihapuskan';
$string['deletesure'] = 'Anda pasti ingin menghapuskan pos ini?';
$string['digestmailheader'] = 'Ini adalah ringkasan harian untuk pos terbaru bagi forum $a->sitename. Untuk mengubah pilihan forum anda, sila ke $a->userprefs.';
$string['digestmailprefs'] = 'profil pengguna anda';
$string['digestmailsubject'] = '$a: ringkasan forum';
$string['digestsentusers'] = 'Ringkasan melalui email telah dihantar kepada $a pengguna.';
$string['discussion'] = 'Perbincangan';
$string['discussionmoved'] = 'Pebincangan ini telah dipindahkan ke \'$a\'.';
$string['discussionname'] = 'Nama perbincangan';
$string['discussions'] = 'Perbincangan';
$string['discussionsstartedby'] = 'Perbincangan yang dimulakan oleh $a';
$string['discussionsstartedbyrecent'] = 'Perbincangan yang baru sahaja dimulakan oleh $a';
$string['discussthistopic'] = 'Bincang topik ini';
$string['eachuserforum'] = 'Setiap orang pos satu perbincangan';
$string['edit'] = 'Ubah';
$string['editing'] = 'Ubah';
$string['emptymessage'] = 'Kesilapan berlaku pada pos anda. Mungkin ada yang anda tinggalkan kosong, atau saiz kepilan terlalu besar. Perubahan anda TIDAK disimpan.';
$string['everyonecanchoose'] = 'Setiap orang boleh memilih untuk dilanggani';
$string['everyoneissubscribed'] = 'Setiap orang melanggani forum ini';
$string['forcesubscribe'] = 'Paksa setiap orang dilanggani';
$string['forcesubscribeq'] = 'Paksa setiap orang dilanggani?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Pengenalan forum';
$string['forumname'] = 'Nama forum';
$string['forums'] = 'Forum';
$string['forumtype'] = 'Jenis forum';
$string['generalforum'] = 'Forum standad untuk penggunaan umum';
$string['generalforums'] = 'Forum Umum';
$string['inforum'] = 'pada $a';
$string['intronews'] = 'Berita umum dan pengumuman';
$string['introsocial'] = 'Forum terbuka untuk perbualan tentang apapun yang anda inginkan';
$string['introteacher'] = 'Forum untuk guru-hanya nota dan perbincangan';
$string['lastpost'] = 'Pos terdahulu';
$string['learningforums'] = 'Forum Pembelajaran';
$string['maxattachmentsize'] = 'Saiz maksimum kepilan';
$string['maxtimehaspassed'] = 'Maaf, tempoh maksimum untuk pengubahan pos ini ($a) telah dilewati!';
$string['message'] = 'Pesanan';
$string['modeflatnewestfirst'] = 'Papar balasan secara biasa, dari yang terbaru';
$string['modeflatoldestfirst'] = 'Papar balasan secara biasa, dari yang terlama';
$string['modenested'] = 'Papar balas dengan format tersarang';
$string['modethreaded'] = 'Papar balas dengan format bercabang';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Forum';
$string['more'] = 'lebih lanjut';
$string['movethisdiscussionto'] = 'Pindahkan perbincangan ini ke ...';
$string['namenews'] = 'Forum Berita';
$string['namesocial'] = 'Forum Sosial';
$string['nameteacher'] = 'Forum Guru';
$string['newforumposts'] = 'Pos forum baru';
$string['nodiscussions'] = 'Belum ada topik perbincangan di dalam forum ini';
$string['noguestpost'] = 'Maaf, tetamu tidak dibenarkan mengepos';
$string['nomorepostscontaining'] = 'Tiada lagi pos yang mengandungi \'$a\' dijumpai';
$string['nonews'] = 'Belum ada berita yang diposkan';
$string['noposts'] = 'Tidak ada pos';
$string['nopostscontaining'] = 'Tiada pos yang mengandungi \'$a\' dijumpai';
$string['nosubscribers'] = 'Tiada pelangan didalam forum ini';
$string['notingroup'] = 'Maaf, anda perlu menjadi ahli kumpulan untuk melihat forum ini.';
$string['nownotsubscribed'] = '$a->name TIDAK akan menerima salinan \'$a->forum\' melalui email.';
$string['nowsubscribed'] = '$a->name akan menerima salinan \'$a->forum\' melalui email.';
$string['numposts'] = '$a mengepos';
$string['olderdiscussions'] = 'Perbincangan terdahulu';
$string['openmode0'] = 'Tiada perbincangan, tiada balas';
$string['openmode1'] = 'Tiada perbincangan, tetapi balas dibenarkan';
$string['openmode2'] = 'Perbincangan dan balas dibenarkan';
$string['parent'] = 'Tunjukkan induk';
$string['parentofthispost'] = 'Induk pos ini';
$string['postadded'] = 'Pos anda berjaya ditambahkan.<P>Anda mempunyai $a untuk mengubahnya jika anda ingin membuat perubahan.';
$string['postincontext'] = 'Lihat pos ini di dalam konteks';
$string['postmailinfo'] = 'Ini adalah salinan pesanan yang diposkan di laman web $a. Untuk membalas melalui laman web tersebut, klik pada pautan ini:';
$string['postrating1'] = 'Tidak Berkaitan';
$string['postrating2'] = 'Tidak Berkenaan Tetapi Berkaitan';
$string['postrating3'] = 'Berkaitan';
$string['posts'] = 'Pos';
$string['posttoforum'] = 'Pos ke forum';
$string['postupdated'] = 'Pos anda telah dikemaskini';
$string['processingdigest'] = 'Memproses ringkasan email bagi $a';
$string['processingpost'] = 'Memproses pos $a';
$string['prune'] = 'Putuskan';
$string['prunedpost'] = 'Perbincangan baru telah dimulakan daripada pos tersebut';
$string['pruneheading'] = 'Putuskan pos dan pindah ke perbincangan baru';
$string['rate'] = 'Nilai';
$string['rating'] = 'Penilaian';
$string['ratingeveryone'] = 'Sesiapa boleh menilai pos';
$string['ratingno'] = 'Tiada penilaian';
$string['ratingonlyteachers'] = 'Hanya $a boleh menilai pos';
$string['ratingpublic'] = '$a boleh melihat penilaian semua';
$string['ratingpublicnot'] = '$a hanya boleh melihat penilaian masing-masing';
$string['ratings'] = 'Penilaian';
$string['ratingssaved'] = 'Penilaian telah disimpan';
$string['ratingsuse'] = 'Guna penilaian';
$string['ratingtime'] = 'Hadkan penilaian pos di dalam lingkungan tarikh ini:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Baca keseluruhan topik';
$string['replies'] = 'Balas';
$string['repliesmany'] = '$a balas setakat ini';
$string['repliesone'] = '$a balas setakat ini';
$string['reply'] = 'Balas';
$string['replyforum'] = 'Balas ke forum';
$string['rsssubscriberssdiscussions'] = 'Paparkan RSS untuk \'$a\' diskusi';
$string['rsssubscriberssposts'] = 'Paparkan RSS untuk \'$a\' pos';
$string['search'] = 'Carian';
$string['searchforums'] = 'Cari dlm forum';
$string['searcholderposts'] = 'Cari pos-pos lama';
$string['searchresults'] = 'Hasil pencarian';
$string['sendinratings'] = 'Kirim penilaian terakhir saya';
$string['showsubscribers'] = 'Pamerkan para pelanggan';
$string['singleforum'] = 'Perbincangan medah tunggal';
$string['startedby'] = 'Dimulakan oleh';
$string['subject'] = 'Subjek';
$string['subscribe'] = 'Langgani forum ini';
$string['subscribeall'] = 'Langgankan semua kepada forum ini';
$string['subscribed'] = 'Berlanggan';
$string['subscribenone'] = 'Berhentikan langganan semua bagi forum ini';
$string['subscribers'] = 'Pelanggan';
$string['subscribersto'] = 'Pelanggan pada \'$a\'';
$string['subscribestart'] = 'Kirimkan salinan email bagi pos forum ini kepada saya';
$string['subscribestop'] = 'Saya tidak mahu salinan email bagi pos untuk forum ini';
$string['subscription'] = 'Langganan';
$string['subscriptions'] = 'Langganan';
$string['unsubscribe'] = 'Berhenti melanggan dari forum ini';
$string['unsubscribed'] = 'Berhenti melanggan';
$string['unsubscribeshort'] = 'Berhenti melanggan';
$string['youratedthis'] = 'Anda menilai ini';
$string['yournewtopic'] = 'Topik perbincangan baru anda ';
$string['yourreply'] = 'Balas anda';

?>

==> moodle-1.5.tgz: moodle/lang/ms/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.3.1 (2004052501)


$string['addanewdiscussion'] = 'Tambah topik perbincangan baru';
$string['addanewtopic'] = 'Tambah topik';
$string['allowchoice'] = 'Benarkan semua orang memilih';
$string['allowdiscussions'] = 'Bolehkah $a mengepos pada forum ini?';
$string['allowratings'] = 'Benarkan penghantaran dinilai?';
$string['allowsdiscussions'] = 'Forum ini membenarkan setiap orang untuk memulai sebuah topik perbincangan.';
$string['anyfile'] = 'Sebarang fail';
$string['attachment'] = 'Kepilan';
$string['bynameondate'] = 'dari $a->name - $a->date';
$string['configdisplaymode'] = 'Mod paparan asal untuk perbincangan jika belum ditetapkan.';
$string['configenablerssfeeds'] = 'Ini akan membenarkan RSS bagi semua forum. Anda masih perlu menukar setting RSS bagi setiap forum.';
$string['configlongpost'] = 'Sebarang pos melebihi had ini (tidak termasuk HTML) dianggap panjang.';
$string['configmanydiscussions'] = 'Bilangan perbincangan maksimum yang dipaparkan di dalam forum untuk setiap mukasurat';
$string['configmaxbytes'] = 'Sazi maximum bagi semua kepilan pada forum laman ini (bergantung kepada had kursus dll)';
$string['configreplytouser'] = 'Apabila pos forum dihantar, perlukah email pengguna disertakan sekali supaya penerima dapat menjawab terus kepadanya tanpa melalui forum? Walaupun disetkan kepada \'Ya\' pengguna boleh memilih untuk merahsiakan alamat email mereka.';
$string['configshortpost'] = 'Sebarang pos tidak melebihi had ini (tidak termasuk HTML) dianggap pendek.';
$string['couldnotadd'] = 'Tidak dapat menambahkan pos anda kerana kesalahan yang tidak diketahui';
$string['couldnotdeleteratings'] = 'Maaf, tidak dapat dipadamkan kerana ianya telah dinilai.';
$string['couldnotdeletereplies'] = 'Maaf, tidak dapat dipadamkan kerana ianya telah dibalas.';
$string['couldnotupdate'] = 'Tidak dapat mengemaskini pos anda kerana kesalahan yang tidak diketahui';
$string['delete'] = 'Hapus';
$string['deleteddiscussion'] = 'Topik perbincangan telah dihapuskan';
$string['deletedpost'] = 'Pos telah dihapuskan';
$string['deletesure'] = 'Anda pasti ingin menghapuskan pos ini?';
$string['digestmailheader'] = 'Ini adalah ringkasan harian untuk pos terbaru bagi forum $a->sitename. Untuk mengubah pilihan forum anda, sila ke $a->userprefs.';
$string['digestmailprefs'] = 'profil pengguna anda';
$string['digestmailsubject'] = '$a: ringkasan forum';
$string['digestsentusers'] = 'Ringkasan melalui email telah dihantar kepada $a pengguna.';
$string['discussion'] = 'Perbincangan';
$string['discussionmoved'] = 'Pebincangan ini telah dipindahkan ke \'$a\'.';
$string['discussionname'] = 'Nama perbincangan';
$string['discussions'] = 'Perbincangan';
$string['discussionsstartedby'] = 'Perbincangan yang dimulakan oleh $a';
$string['discussionsstartedbyrecent'] = 'Perbincangan yang baru sahaja dimulakan oleh $a';
$string['discussthistopic'] = 'Bincang topik ini';
$string['eachuserforum'] = 'Setiap orang pos satu perbincangan';
$string['edit'] = 'Ubah';
$string['editing'] = 'Ubah';
$string['emptymessage'] = 'Kesilapan berlaku pada pos anda. Mungkin ada yang anda tinggalkan kosong, atau saiz kepilan terlalu besar. Perubahan anda TIDAK disimpan.';
$string['everyonecanchoose'] = 'Setiap orang boleh memilih untuk dilanggani';
$string['everyoneissubscribed'] = 'Setiap orang melanggani forum ini';
$string['forcesubscribe'] = 'Paksa setiap orang dilanggani';
$string['forcesubscribeq'] = 'Paksa setiap orang dilanggani?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Pengenalan forum';
$string['forumname'] = 'Nama forum';
$string['forums'] = 'Forum';
$string['forumtype'] = 'Jenis forum';
$string['generalforum'] = 'Forum standad untuk penggunaan umum';
$string['generalforums'] = 'Forum Umum';
$string['inforum'] = 'pada $a';
$string['intronews'] = 'Berita umum dan pengumuman';
$string['introsocial'] = 'Forum terbuka untuk perbualan tentang apapun yang anda inginkan';
$string['introteacher'] = 'Forum untuk guru-hanya nota dan perbincangan';
$string['lastpost'] = 'Pos terdahulu';
$string['learningforums'] = 'Forum Pembelajaran';
$string['maxattachmentsize'] = 'Saiz maksimum kepilan';
$string['maxtimehaspassed'] = 'Maaf, tempoh maksimum untuk pengubahan pos ini ($a) telah dilewati!';
$string['message'] = 'Pesanan';
$string['modeflatnewestfirst'] = 'Papar balasan secara biasa, dari yang terbaru';
$string['modeflatoldestfirst'] = 'Papar balasan secara biasa, dari yang terlama';
$string['modenested'] = 'Papar balas dengan format tersarang';
$string['modethreaded'] = 'Papar balas dengan format bercabang';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Forum';
$string['more'] = 'lebih lanjut';
$string['movethisdiscussionto'] = 'Pindahkan perbincangan ini ke ...';
$string['namenews'] = 'Forum Berita';
$string['namesocial'] = 'Forum Sosial';
$string['nameteacher'] = 'Forum Guru';
$string['newforumposts'] = 'Pos forum baru';
$string['nodiscussions'] = 'Belum ada topik perbincangan di dalam forum ini';
$string['noguestpost'] = 'Maaf, tetamu tidak dibenarkan mengepos';
$string['nomorepostscontaining'] = 'Tiada lagi pos yang mengandungi \'$a\' dijumpai';
$string['nonews'] = 'Belum ada berita yang diposkan';
$string['noposts'] = 'Tidak ada pos';
$string['nopostscontaining'] = 'Tiada pos yang mengandungi \'$a\' dijumpai';
$string['nosubscribers'] = 'Tiada pelangan didalam forum ini';
$string['notingroup'] = 'Maaf, anda perlu menjadi ahli kumpulan untuk melihat forum ini.';
$string['nownotsubscribed'] = '$a->name TIDAK akan menerima salinan \'$a->forum\' melalui email.';
$string['nowsubscribed'] = '$a->name akan menerima salinan \'$a->forum\' melalui email.';
$string['numposts'] = '$a mengepos';
$string['olderdiscussions'] = 'Perbincangan terdahulu';
$string['openmode0'] = 'Tiada perbincangan, tiada balas';
$string['openmode1'] = 'Tiada perbincangan, tetapi balas dibenarkan';
$string['openmode2'] = 'Perbincangan dan balas dibenarkan';
$string['parent'] = 'Tunjukkan induk';
$string['parentofthispost'] = 'Induk pos ini';
$string['postadded'] = 'Pos anda berjaya ditambahkan.<br />Anda mempunyai $a untuk mengubahnya jika anda ingin membuat perubahan.';
$string['postincontext'] = 'Lihat pos ini di dalam konteks';
$string['postmailinfo'] = 'Ini adalah salinan pesanan yang diposkan di laman web $a. Untuk membalas melalui laman web tersebut, klik pada pautan ini:';
$string['postrating1'] = 'Tidak Berkaitan';
$string['postrating2'] = 'Tidak Berkenaan Tetapi Berkaitan';
$string['postrating3'] = 'Berkaitan';
$string['posts'] = 'Pos';
$string['posttoforum'] = 'Pos ke forum';
$string['postupdated'] = 'Pos anda telah dikemaskini';
$string['processingdigest'] = 'Memproses ringkasan email bagi $a';
$string['processingpost'] = 'Memproses pos $a';
$string['prune'] = 'Putuskan';
$string['prunedpost'] = 'Perbincangan baru telah dimulakan daripada pos tersebut';
$string['pruneheading'] = 'Putuskan pos dan pindah ke perbincangan baru';
$string['rate'] = 'Nilai';
$string['rating'] = 'Penilaian';
$string['ratingeveryone'] = 'Sesiapa boleh menilai pos';
$string['ratingno'] = 'Tiada penilaian';
$string['ratingonlyteachers'] = 'Hanya $a boleh menilai pos';
$string['ratingpublic'] = '$a boleh melihat penilaian semua';
$string['ratingpublicnot'] = '$a hanya boleh melihat penilaian masing-masing';
$string['ratings'] = 'Penilaian';
$string['ratingssaved'] = 'Penilaian telah disimpan';
$string['ratingsuse'] = 'Guna penilaian';
$string['ratingtime'] = 'Hadkan penilaian pos di dalam lingkungan tarikh ini:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Baca keseluruhan topik';
$string['replies'] = 'Balas';
$string['repliesmany'] = '$a balas setakat ini';
$string['repliesone'] = '$a balas setakat ini';
$string['reply'] = 'Balas';
$string['replyforum'] = 'Balas ke forum';
$string['rsssubscriberssdiscussions'] = 'Paparkan RSS untuk \'$a\' diskusi';
$string['rsssubscriberssposts'] = 'Paparkan RSS untuk \'$a\' pos';
$string['search'] = 'Carian';
$string['searchforums'] = 'Cari dlm forum';
$string['searcholderposts'] = 'Cari pos-pos lama';
$string['searchresults'] = 'Hasil pencarian';
$string['sendinratings'] = 'Kirim penilaian terakhir saya';
$string['showsubscribers'] = 'Pamerkan para pelanggan';
$string['singleforum'] = 'Perbincangan medah tunggal';
$string['startedby'] = 'Dimulakan oleh';
$string['subject'] = 'Subjek';
$string['subscribe'] = 'Langgani forum ini';
$string['subscribeall'] = 'Langgankan semua kepada forum ini';
$string['subscribed'] = 'Berlanggan';
$string['subscribenone'] = 'Berhentikan langganan semua bagi forum ini';
$string['subscribers'] = 'Pelanggan';
$string['subscribersto'] = 'Pelanggan pada \'$a\'';
$string['subscribestart'] = 'Kirimkan salinan email bagi pos forum ini kepada saya';
$string['subscribestop'] = 'Saya tidak mahu salinan email bagi pos untuk forum ini';
$string['subscription'] = 'Langganan';
$string['subscriptions'] = 'Langganan';
$string['unsubscribe'] = 'Berhenti melanggan dari forum ini';
$string['unsubscribed'] = 'Berhenti melanggan';
$string['unsubscribeshort'] = 'Berhenti melanggan';
$string['youratedthis'] = 'Anda menilai ini';
$string['yournewtopic'] = 'Topik perbincangan baru anda ';
$string['yourreply'] = 'Balas anda';

?>
